You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/05/20 20:52:29 UTC

svn commit: r658390 [13/32] - in /tapestry/tapestry5/branches/hlship-20080520: ./ quickstart/src/main/resources/META-INF/ quickstart/src/main/resources/archetype-resources/src/main/java/pages/ quickstart/src/main/resources/archetype-resources/src/main/...

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentClassTransformWorker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentClassTransformWorker.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentClassTransformWorker.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentClassTransformWorker.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.model.MutableComponentModel;
+import org.apache.tapestry5.model.MutableComponentModel;
 
 /**
  * Interface for a set of objects that can perform component class transformations. Implementations should be
  * multithreaded, ideally they should be stateless (all necessary state can be stored in the {@link
- * org.apache.tapestry.services.ClassTransformation}).
+ * org.apache.tapestry5.services.ClassTransformation}).
  */
 public interface ComponentClassTransformWorker
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentDefaultProvider.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentDefaultProvider.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentDefaultProvider.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentDefaultProvider.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.*;
+import org.apache.tapestry5.*;
 
 /**
  * A service that can be injected into a component to provide common defaults for various types of parameters.
@@ -46,7 +46,7 @@
      * based on type.
      *
      * @param parameterName the name of the parameter whose type is used to locate a {@link
-     *                      org.apache.tapestry.services.ValueEncoderFactory}
+     *                      org.apache.tapestry5.services.ValueEncoderFactory}
      * @param resources     the resources of the component, from which parameter and its type are extracted
      * @return the value encoder, or null if the type of the parameter is not known
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestHandler.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestHandler.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.corelib.components.ActionLink;
-import org.apache.tapestry.corelib.components.Form;
+import org.apache.tapestry5.corelib.components.ActionLink;
+import org.apache.tapestry5.corelib.components.Form;
 
 import java.io.IOException;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestParameters.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestParameters.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventResultProcessor.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventResultProcessor.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.io.IOException;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentLayer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentLayer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMessagesSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMessagesSource.java Tue May 20 11:51:35 2008
@@ -14,9 +14,9 @@
 
 package org.apache.tapestry5.services;
 
-import org.apache.tapestry.internal.event.InvalidationEventHub;
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.model.ComponentModel;
+import org.apache.tapestry5.internal.event.InvalidationEventHub;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.model.ComponentModel;
 
 import java.util.Locale;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMethodAdvice.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMethodAdvice.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Context.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Context.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.io.File;
 import java.net.URL;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ContextProvider.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ContextProvider.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ContextProvider.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ContextProvider.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ContextValueEncoder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ContextValueEncoder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ContextValueEncoder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ContextValueEncoder.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * Used to convert values used in event contexts to client string representations and back.
  *
- * @See org.apache.tapestry.ValueEncoder
- * @see org.apache.tapestry.ioc.services.TypeCoercer
+ * @See org.apache.tapestry5.ValueEncoder
+ * @see org.apache.tapestry5.ioc.services.TypeCoercer
  */
 public interface ContextValueEncoder
 {
@@ -27,7 +27,7 @@
      *
      * @param value to convert (may not be null)
      * @return string representation of the value
-     * @see org.apache.tapestry.ValueEncoder#toClient(Object)
+     * @see org.apache.tapestry5.ValueEncoder#toClient(Object)
      */
     String toClient(Object value);
 
@@ -37,7 +37,7 @@
      * @param requiredType required type to convert the string to
      * @param clientValue  value obtained from context passed from client
      * @return the client value converted or coerced into a server value
-     * @see org.apache.tapestry.ValueEncoder#toValue(String)
+     * @see org.apache.tapestry5.ValueEncoder#toValue(String)
      */
     <T> T toValue(Class<T> requiredType, String clientValue);
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Cookies.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Cookies.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Core.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Core.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/DataTypeAnalyzer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/DataTypeAnalyzer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/DataTypeAnalyzer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/DataTypeAnalyzer.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.corelib.components.BeanEditForm;
-import org.apache.tapestry.corelib.components.Grid;
-import org.apache.tapestry.ioc.services.PropertyAdapter;
+import org.apache.tapestry5.corelib.components.BeanEditForm;
+import org.apache.tapestry5.corelib.components.Grid;
+import org.apache.tapestry5.ioc.services.PropertyAdapter;
 
 /**
  * Used by {@link BeanModelSource} to identify the type of data associated with a particular property (represented as a
@@ -30,7 +30,7 @@
  * @see Grid
  * @see BeanEditForm
  * @see BeanBlockSource
- * @see org.apache.tapestry.services.TapestryModule#contributeDataTypeAnalyzer(org.apache.tapestry.ioc.OrderedConfiguration,
+ * @see org.apache.tapestry5.services.TapestryModule#contributeDataTypeAnalyzer(org.apache.tapestry5.ioc.OrderedConfiguration,
  *      DataTypeAnalyzer)
  */
 public interface DataTypeAnalyzer

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Dispatcher.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Dispatcher.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Environment.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Environment.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.util.NoSuchElementException;
 
@@ -24,8 +24,8 @@
  * type. Most often, a stack has zero or one elements, but on occasion, a particular component will push an override
  * onto the stack for the benefit of the components it encloses.
  *
- * @see org.apache.tapestry.annotation.Environmental
- * @see org.apache.tapestry.services.EnvironmentalShadowBuilder
+ * @see org.apache.tapestry5.annotations.Environmental
+ * @see org.apache.tapestry5.services.EnvironmentalShadowBuilder
  */
 public interface Environment
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/EnvironmentalShadowBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/EnvironmentalShadowBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/EnvironmentalShadowBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/EnvironmentalShadowBuilder.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.annotation.Environmental;
-import org.apache.tapestry.ioc.services.PropertyShadowBuilder;
+import org.apache.tapestry5.annotations.Environmental;
+import org.apache.tapestry5.ioc.services.PropertyShadowBuilder;
 
 /**
  * Much like {@link PropertyShadowBuilder}, except that instead of accessing a property of some other service, it

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ExceptionReporter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ExceptionReporter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ExceptionReporter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ExceptionReporter.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * Interface implemented by a page used for reporting exceptions.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldFilter.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * Used by {@link ClassTransformation#findFields(FieldFilter)} to identify which fields to keep.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldValidatorDefaultSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldValidatorDefaultSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldValidatorSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldValidatorSource.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.Field;
-import org.apache.tapestry.FieldValidator;
-import org.apache.tapestry.Validator;
-import org.apache.tapestry.corelib.components.BeanEditForm;
-import org.apache.tapestry.ioc.Messages;
+import org.apache.tapestry5.Field;
+import org.apache.tapestry5.FieldValidator;
+import org.apache.tapestry5.Validator;
+import org.apache.tapestry5.corelib.components.BeanEditForm;
+import org.apache.tapestry5.ioc.Messages;
 
 import java.util.Locale;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FormSupport.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FormSupport.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/HttpServletRequestHandler.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/HttpServletRequestHandler.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -21,7 +21,7 @@
 /**
  * Service interface for the HttpServletRequestHandler pipeline service.
  *
- * @see org.apache.tapestry.services.HttpServletRequestFilter
+ * @see org.apache.tapestry5.services.HttpServletRequestFilter
  */
 public interface HttpServletRequestHandler
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/InjectionProvider.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/InjectionProvider.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/LibraryMapping.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/LibraryMapping.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * Used to configure the {@link ComponentClassResolver}, to allow it to map prefixes to library root packages (the
@@ -24,7 +24,7 @@
  * <dt>components</dt> <dd>contains components</dd> <dt>mixins</dt> <dd>contains component mixins</dd> <dt>base</dt>
  * <dd>contains base classes</dd> </dl>
  *
- * @see org.apache.tapestry.services.TapestryModule#contributeComponentClassResolver(org.apache.tapestry.ioc.Configuration)
+ * @see org.apache.tapestry5.services.TapestryModule#contributeComponentClassResolver(org.apache.tapestry5.ioc.Configuration)
  */
 public final class LibraryMapping
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupRenderer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupRenderer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MethodFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MethodFilter.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * Used by {@link ClassTransformation#findMethods(MethodFilter)} to accept or reject each method.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/NullFieldStrategySource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/NullFieldStrategySource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestFilter.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.io.IOException;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestHandler.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestHandler.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldBundle.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldBundle.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * Encapsulates persisted property information for an entire page.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldChange.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldChange.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldChange.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldChange.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * Represents a previously stored change to a persistent field, within the context of a particular page of the

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldStrategy.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldStrategy.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentLocale.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentLocale.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.util.Locale;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyConduitSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyConduitSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyOutputContext.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyOutputContext.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.corelib.components.Grid;
-import org.apache.tapestry.ioc.Messages;
+import org.apache.tapestry5.corelib.components.Grid;
+import org.apache.tapestry5.ioc.Messages;
 
 /**
  * Provides context information needed when displaying a value. This interface is an integral part of the {@link Grid}
  * and similar output components.    It is made available to components via an {@link
- * org.apache.tapestry.annotation.Environmental} annotation.
+ * org.apache.tapestry5.annotations.Environmental} annotation.
  */
 public interface PropertyOutputContext
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Request.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Request.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Request.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Request.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.util.List;
 import java.util.Locale;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestExceptionHandler.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestExceptionHandler.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestExceptionHandler.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestExceptionHandler.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.io.IOException;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestGlobals.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestGlobals.java Tue May 20 11:51:35 2008
@@ -14,8 +14,8 @@
 
 package org.apache.tapestry5.services;
 
-import org.apache.tapestry.services.Request;
-import org.apache.tapestry.services.Response;
+import org.apache.tapestry5.services.Request;
+import org.apache.tapestry5.services.Response;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestHandler.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestHandler.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestHandler.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestHandler.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.io.IOException;
 
@@ -20,7 +20,7 @@
  * Service interface for the RequestHandler pipeline service. An ordered configuration of filters may be contributed to
  * the service.
  *
- * @see org.apache.tapestry.services.RequestFilter
+ * @see org.apache.tapestry5.services.RequestFilter
  */
 
 public interface RequestHandler

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ResourceDigestGenerator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ResourceDigestGenerator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ResourceDigestGenerator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ResourceDigestGenerator.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.internal.services.ClasspathAssetFactory;
-import org.apache.tapestry.ioc.Resource;
-import org.apache.tapestry.ioc.internal.util.ClasspathResource;
+import org.apache.tapestry5.internal.services.ClasspathAssetFactory;
+import org.apache.tapestry5.ioc.Resource;
+import org.apache.tapestry5.ioc.internal.util.ClasspathResource;
 
 import java.net.URL;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Response.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Response.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Response.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Response.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.Link;
+import org.apache.tapestry5.Link;
 
 import java.io.IOException;
 import java.io.OutputStream;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ServletApplicationInitializer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ServletApplicationInitializer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ServletApplicationInitializer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ServletApplicationInitializer.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import javax.servlet.ServletContext;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ServletApplicationInitializerFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ServletApplicationInitializerFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Session.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Session.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import javax.servlet.http.HttpSession;
 import java.util.List;
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestFilter.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.io.IOException;
 
 /**
  * Filter interface for {@link ComponentEventRequestHandler}.
  *
  * @see org.apache.tapestry.services.TapestryModule#contributeComponentEventRequestHandler(org.apache.tapestry.ioc.OrderedConfiguration,
  *      org.apache.tapestry.internal.services.RequestEncodingInitializer, ComponentEventRequestHandler ,
  *      org.apache.tapestry.ioc.ObjectLocator) }
  */
 public interface ComponentEventRequestFilter
 {
@@ -12,16 +12,16 @@
  * Filter interface for {@link ComponentEventRequestHandler}.
  *
- * @see org.apache.tapestry.services.TapestryModule#contributeComponentEventRequestHandler(org.apache.tapestry.ioc.OrderedConfiguration,
- *      org.apache.tapestry.internal.services.RequestEncodingInitializer, ComponentEventRequestHandler ,
- *      org.apache.tapestry.ioc.ObjectLocator) }
+ * @see org.apache.tapestry5.services.TapestryModule#contributeComponentEventRequestHandler(org.apache.tapestry5.ioc.OrderedConfiguration,
+ *      org.apache.tapestry5.internal.services.RequestEncodingInitializer, ComponentEventRequestHandler ,
+ *      org.apache.tapestry5.ioc.ObjectLocator) }
  */
 public interface ComponentEventRequestFilter

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestHandler.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestHandler.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestParameters.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventRequestParameters.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.EventContext;
-import org.apache.tapestry.ioc.internal.util.Defense;
+import org.apache.tapestry5.EventContext;
+import org.apache.tapestry5.ioc.internal.util.Defense;
 
 /**
  * Encapsulates all the information that may be provided in a component event request URL.
@@ -92,7 +92,7 @@
 
     /**
      * The name of the page containing the component that was triggered. Usually this is the same as the active page,
      * but because of {@link org.apache.tapestry.Block} and similar constructs, a component from other than the active
      * page may be rendered with the active page.
      */
     public String getContainingPageName()
@@ -111,7 +111,7 @@
 
     /**
      * The type of event.  When not specified in the URL, a default type of "action" ({@link
      * org.apache.tapestry.EventConstants#ACTION}) is provided.
      */
     public String getEventType()
     {
@@ -121,8 +121,8 @@
     /**
      * The activation context for the <em>active page</em>, possibly empty (but not null).
      *
      * @see org.apache.tapestry.ComponentResourcesCommon#triggerContextEvent(String, org.apache.tapestry.EventContext,
      *      org.apache.tapestry.ComponentEventCallback)
      */
     public EventContext getPageActivationContext()
     {
@@ -132,8 +132,8 @@
     /**
      * The event context information passed in the URL.  Possibly empty (not not null).
      *
      * @see org.apache.tapestry.ComponentResourcesCommon#triggerContextEvent(String, org.apache.tapestry.EventContext,
      *      org.apache.tapestry.ComponentEventCallback)
      */
     public EventContext getEventContext()
     {
@@ -92,7 +92,7 @@
     /**
      * The name of the page containing the component that was triggered. Usually this is the same as the active page,
-     * but because of {@link org.apache.tapestry.Block} and similar constructs, a component from other than the active
+     * but because of {@link org.apache.tapestry5.Block} and similar constructs, a component from other than the active
      * page may be rendered with the active page.
      */
@@ -111,7 +111,7 @@
     /**
      * The type of event.  When not specified in the URL, a default type of "action" ({@link
-     * org.apache.tapestry.EventConstants#ACTION}) is provided.
+     * org.apache.tapestry5.EventConstants#ACTION}) is provided.
      */
     public String getEventType()
@@ -121,8 +121,8 @@
      * The activation context for the <em>active page</em>, possibly empty (but not null).
      *
-     * @see org.apache.tapestry.ComponentResourcesCommon#triggerContextEvent(String, org.apache.tapestry.EventContext,
-     *      org.apache.tapestry.ComponentEventCallback)
+     * @see org.apache.tapestry5.ComponentResourcesCommon#triggerContextEvent(String, org.apache.tapestry5.EventContext,
+     *      org.apache.tapestry5.ComponentEventCallback)
      */
     public EventContext getPageActivationContext()
@@ -132,8 +132,8 @@
      * The event context information passed in the URL.  Possibly empty (not not null).
      *
-     * @see org.apache.tapestry.ComponentResourcesCommon#triggerContextEvent(String, org.apache.tapestry.EventContext,
-     *      org.apache.tapestry.ComponentEventCallback)
+     * @see org.apache.tapestry5.ComponentResourcesCommon#triggerContextEvent(String, org.apache.tapestry5.EventContext,
+     *      org.apache.tapestry5.ComponentEventCallback)
      */
     public EventContext getEventContext()

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventResultProcessor.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentEventResultProcessor.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentLayer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentLayer.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -24,8 +24,8 @@
 /**
  * Marker annotation used to identify a service from the component layer that conflicts, in terms of service interface,
  * with a service from elsewhere. In particular, this is used to disambiguate {@link
  * org.apache.tapestry.ioc.services.ClassFactory} which has one implementation (marked with {@link
  * org.apache.tapestry.ioc.services.Builtin} and another with this annotation.
  */
 @Target(
         { PARAMETER, FIELD })
@@ -24,8 +24,8 @@
  * Marker annotation used to identify a service from the component layer that conflicts, in terms of service interface,
  * with a service from elsewhere. In particular, this is used to disambiguate {@link
- * org.apache.tapestry.ioc.services.ClassFactory} which has one implementation (marked with {@link
- * org.apache.tapestry.ioc.services.Builtin} and another with this annotation.
+ * org.apache.tapestry5.ioc.services.ClassFactory} which has one implementation (marked with {@link
+ * org.apache.tapestry5.ioc.services.Builtin} and another with this annotation.
  */
 @Target(

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMessagesSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMessagesSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMethodAdvice.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMethodAdvice.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * An object that receives control around an "advised" method of a component. The advise can query or even replace
  * method parameters.  After invoking {@link org.apache.tapestry.services.ComponentMethodInvocation#proceed()}, the
  * advise may query and override thrown exceptions or the return value of the invocation.
  *
  * @see ClassTransformation#advise(TransformMethodSignature, ComponentMethodAdvice)
@@ -12,11 +12,11 @@
 /**
  * An object that receives control around an "advised" method of a component. The advise can query or even replace
- * method parameters.  After invoking {@link org.apache.tapestry.services.ComponentMethodInvocation#proceed()}, the
+ * method parameters.  After invoking {@link org.apache.tapestry5.services.ComponentMethodInvocation#proceed()}, the
  * advise may query and override thrown exceptions or the return value of the invocation.
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMethodInvocation.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMethodInvocation.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMethodInvocation.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentMethodInvocation.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.ComponentResources;
-import org.apache.tapestry.ioc.Invocation;
+import org.apache.tapestry5.ComponentResources;
+import org.apache.tapestry5.ioc.Invocation;
 
 /**
  * Encapsulates the parameters, thrown exceptions, and result of a method invocation, allowing a {@link
  * org.apache.tapestry.services.ComponentMethodAdvice} to encapsulate the invocation.
  */
 public interface ComponentMethodInvocation extends Invocation
 {
@@ -12,14 +12,14 @@
 /**
  * Encapsulates the parameters, thrown exceptions, and result of a method invocation, allowing a {@link
- * org.apache.tapestry.services.ComponentMethodAdvice} to encapsulate the invocation.
+ * org.apache.tapestry5.services.ComponentMethodAdvice} to encapsulate the invocation.
  */
 public interface ComponentMethodInvocation extends Invocation

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ComponentSource.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.runtime.Component;
+import org.apache.tapestry5.runtime.Component;
 
 /**
  * Used by classes that need to retrieve a component by its complete id, or a page by its logical page name or root
@@ -24,14 +24,14 @@
 public interface ComponentSource
 {
     /**
      * Gets a component by its {@linkplain org.apache.tapestry.ComponentResourcesCommon#getCompleteId() complete id}. If
      * the component id is for a mixin, then the mixin attached to the component will be returned. A mixin's complete id
      * is its container's complete id, suffixed with "$" and the mixin's id (its simple class name).
      *
      * @param completeId complete component id (case insensitive)
      * @return the component
      * @throws IllegalArgumentException if the component can not be found
-     * @see org.apache.tapestry.ComponentResourcesCommon#getCompleteId()
+     * @see org.apache.tapestry5.ComponentResourcesCommon#getCompleteId()
      */
     Component getComponent(String completeId);
 
@@ -24,14 +24,14 @@
 {
     /**
-     * Gets a component by its {@linkplain org.apache.tapestry.ComponentResourcesCommon#getCompleteId() complete id}. If
+     * Gets a component by its {@linkplain org.apache.tapestry5.ComponentResourcesCommon#getCompleteId() complete id}. If
      * the component id is for a mixin, then the mixin attached to the component will be returned. A mixin's complete id
      * is its container's complete id, suffixed with "$" and the mixin's id (its simple class name).

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Context.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Context.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Cookies.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Cookies.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * Used by other services to obtain cookie values for the current request.
@@ -28,7 +28,7 @@
 
     /**
      * Creates or updates a cookie value. The value is stored using a max age (in seconds) defined by the symbol
      * <code>org.apache.tapestry.default-cookie-max-age</code>. The factory default for this value is the equivalent of
      * one week.
      */
 
@@ -28,7 +28,7 @@
     /**
      * Creates or updates a cookie value. The value is stored using a max age (in seconds) defined by the symbol
-     * <code>org.apache.tapestry.default-cookie-max-age</code>. The factory default for this value is the equivalent of
+     * <code>org.apache.tapestry5.default-cookie-max-age</code>. The factory default for this value is the equivalent of
      * one week.
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Core.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Core.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Dispatcher.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Dispatcher.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.io.IOException;
 
@@ -20,9 +20,9 @@
  * A dispatcher is responsible for recognizing an incoming request. Dispatchers form an ordered chain of command, with
  * each dispatcher responsible for recognizing requests that it can process.
  *
  * @see org.apache.tapestry.services.TapestryModule#contributeMasterDispatcher(org.apache.tapestry.ioc.OrderedConfiguration,
  *      ClasspathAssetAliasManager, org.apache.tapestry.internal.services.ResourceCache,
  *      org.apache.tapestry.internal.services.ResourceStreamer, PageRenderRequestHandler, ComponentEventRequestHandler,
  *      ComponentClassResolver, ContextValueEncoder, String)
  */
 public interface Dispatcher
@@ -20,9 +20,9 @@
  * each dispatcher responsible for recognizing requests that it can process.
  *
- * @see org.apache.tapestry.services.TapestryModule#contributeMasterDispatcher(org.apache.tapestry.ioc.OrderedConfiguration,
- *      ClasspathAssetAliasManager, org.apache.tapestry.internal.services.ResourceCache,
- *      org.apache.tapestry.internal.services.ResourceStreamer, PageRenderRequestHandler, ComponentEventRequestHandler,
+ * @see org.apache.tapestry5.services.TapestryModule#contributeMasterDispatcher(org.apache.tapestry5.ioc.OrderedConfiguration,
+ *      ClasspathAssetAliasManager, org.apache.tapestry5.internal.services.ResourceCache,
+ *      org.apache.tapestry5.internal.services.ResourceStreamer, PageRenderRequestHandler, ComponentEventRequestHandler,
  *      ComponentClassResolver, ContextValueEncoder, String)
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Environment.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Environment.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldValidatorDefaultSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldValidatorDefaultSource.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.Field;
-import org.apache.tapestry.FieldValidator;
-import org.apache.tapestry.ioc.AnnotationProvider;
-import org.apache.tapestry.ioc.Messages;
+import org.apache.tapestry5.Field;
+import org.apache.tapestry5.FieldValidator;
+import org.apache.tapestry5.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.Messages;
 
 import java.util.Locale;
 
@@ -29,7 +29,7 @@
 {
     /**
      * Analyzes the property type and property annotations to determine the default set of validations for the property,
      * which are wrapped to form a {@link org.apache.tapestry.FieldValidator} for a field.
      *
      * @param field               Field component for which a validator is being created
      * @param overrideId          the id of the component, used to locate related messages for labels and errors
@@ -29,7 +29,7 @@
     /**
      * Analyzes the property type and property annotations to determine the default set of validations for the property,
-     * which are wrapped to form a {@link org.apache.tapestry.FieldValidator} for a field.
+     * which are wrapped to form a {@link org.apache.tapestry5.FieldValidator} for a field.
      *
      * @param field               Field component for which a validator is being created

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldValidatorSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FieldValidatorSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FormSupport.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/FormSupport.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.ClientElement;
-import org.apache.tapestry.ComponentAction;
-import org.apache.tapestry.Field;
+import org.apache.tapestry5.ClientElement;
+import org.apache.tapestry5.ComponentAction;
+import org.apache.tapestry5.Field;
 
 /**
  * Services provided by an enclosing Form control component to the various form element components it encloses.
  * Implements {@link org.apache.tapestry.ClientElement}, to share the id of the enclosing form.
  *
- * @see org.apache.tapestry.Field
+ * @see org.apache.tapestry5.Field
  */
 public interface FormSupport extends ClientElement
 {
@@ -41,7 +41,7 @@
     <T> void store(T component, ComponentAction<T> action);
 
     /**
      * As with {@link #store(Object, org.apache.tapestry.ComponentAction)}}, but the action is also invoked immediately.
      * This is useful for defining an action that should occur symmetrically in both the render request and the form
      * submission's action request.
      *
@@ -12,17 +12,17 @@
 /**
  * Services provided by an enclosing Form control component to the various form element components it encloses.
- * Implements {@link org.apache.tapestry.ClientElement}, to share the id of the enclosing form.
+ * Implements {@link org.apache.tapestry5.ClientElement}, to share the id of the enclosing form.
  *
@@ -41,7 +41,7 @@
 
     /**
-     * As with {@link #store(Object, org.apache.tapestry.ComponentAction)}}, but the action is also invoked immediately.
+     * As with {@link #store(Object, org.apache.tapestry5.ComponentAction)}}, but the action is also invoked immediately.
      * This is useful for defining an action that should occur symmetrically in both the render request and the form
      * submission's action request.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Heartbeat.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Heartbeat.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Heartbeat.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Heartbeat.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 /**
  * Allows for deferred execution of logic, useful when trying to get multiple components to coordinate behavior. A
@@ -20,7 +20,7 @@
  * is a Label and the field it labels; since we don't know which order the two will render, we can't tell if the field's
  * id is correct until after both have rendered.
  * <p/>
  * The Heartbeat is injected into components via the {@link org.apache.tapestry.annotation.Environmental} annotation.
  */
 public interface Heartbeat
 {
@@ -20,7 +20,7 @@
  * id is correct until after both have rendered.
  * <p/>
- * The Heartbeat is injected into components via the {@link org.apache.tapestry.annotation.Environmental} annotation.
+ * The Heartbeat is injected into components via the {@link org.apache.tapestry5.annotations.Environmental} annotation.
  */
 public interface Heartbeat

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/HttpServletRequestFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/HttpServletRequestFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/HttpServletRequestFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/HttpServletRequestFilter.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import java.io.IOException;
 
 /**
  * Filter interface for {@link org.apache.tapestry.services.HttpServletRequestHandler}.
  */
 public interface HttpServletRequestFilter
 {
@@ -12,14 +12,14 @@
 
 /**
- * Filter interface for {@link org.apache.tapestry.services.HttpServletRequestHandler}.
+ * Filter interface for {@link org.apache.tapestry5.services.HttpServletRequestHandler}.
  */
 public interface HttpServletRequestFilter

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/HttpServletRequestHandler.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/HttpServletRequestHandler.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/InjectionProvider.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/InjectionProvider.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.ioc.ObjectLocator;
-import org.apache.tapestry.model.MutableComponentModel;
+import org.apache.tapestry5.ioc.ObjectLocator;
+import org.apache.tapestry5.model.MutableComponentModel;
 
 /**
  * Provides some form of injection when the value for an {@link org.apache.tapestry.ioc.annotation.Inject} annotation is
  * present. In this case, the provider is responsible for determining the value to be injected from the field name and
  * field type.
  * <p/>
  * This interface will be used as part of a {@link org.apache.tapestry.ioc.services.ChainBuilder chain of command}.
  */
 public interface InjectionProvider
 {
@@ -12,17 +12,17 @@
 
 /**
- * Provides some form of injection when the value for an {@link org.apache.tapestry.ioc.annotation.Inject} annotation is
+ * Provides some form of injection when the value for an {@link org.apache.tapestry5.ioc.annotations.Inject} annotation is
  * present. In this case, the provider is responsible for determining the value to be injected from the field name and
  * field type.
@@ -12,17 +12,17 @@
  * field type.
  * <p/>
- * This interface will be used as part of a {@link org.apache.tapestry.ioc.services.ChainBuilder chain of command}.
+ * This interface will be used as part of a {@link org.apache.tapestry5.ioc.services.ChainBuilder chain of command}.
  */
 public interface InjectionProvider

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/LibraryMapping.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/LibraryMapping.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupRenderer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupRenderer.java Tue May 20 11:51:35 2008
@@ -12,18 +12,18 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.MarkupWriter;
+import org.apache.tapestry5.MarkupWriter;
 
 /**
  * An object which will perform rendering of a page (or portion of a page).  This interface exists to be filtered via
- * {@link org.apache.tapestry.services.MarkupRendererFilter}.
+ * {@link org.apache.tapestry5.services.MarkupRendererFilter}.
  * <p/>
  * The MarkupRenderer service takes an ordered configuration of {@link org.apache.tapestry.services.MarkupRendererFilter}s,
  * which are used for ordinary page rendering (as opposed to {@linkplain org.apache.tapestry.services.PartialMarkupRenderer
  * partial page rendering} for Ajax requests). The MarkupRenderer service may be selected using the {@link
  * org.apache.tapestry.ioc.annotation.Primary} marker annotation.
  */
 public interface MarkupRenderer
 {
@@ -12,18 +12,18 @@
  * <p/>
- * The MarkupRenderer service takes an ordered configuration of {@link org.apache.tapestry.services.MarkupRendererFilter}s,
- * which are used for ordinary page rendering (as opposed to {@linkplain org.apache.tapestry.services.PartialMarkupRenderer
+ * The MarkupRenderer service takes an ordered configuration of {@link org.apache.tapestry5.services.MarkupRendererFilter}s,
+ * which are used for ordinary page rendering (as opposed to {@linkplain org.apache.tapestry5.services.PartialMarkupRenderer
  * partial page rendering} for Ajax requests). The MarkupRenderer service may be selected using the {@link
@@ -12,18 +12,18 @@
  * partial page rendering} for Ajax requests). The MarkupRenderer service may be selected using the {@link
- * org.apache.tapestry.ioc.annotation.Primary} marker annotation.
+ * org.apache.tapestry5.ioc.annotations.Primary} marker annotation.
  */
 public interface MarkupRenderer

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupRendererFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupRendererFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupRendererFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupRendererFilter.java Tue May 20 11:51:35 2008
@@ -12,18 +12,18 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.MarkupWriter;
+import org.apache.tapestry5.MarkupWriter;
 
 /**
  * Filter interface for {@link org.apache.tapestry.services.MarkupRenderer}, which allows for code to execute before
  * and/or after the main rendering process.  Typically, this is to allow for the placement of {@linkplain
- * org.apache.tapestry.services.Environment environmental services}.
+ * org.apache.tapestry5.services.Environment environmental services}.
  *
  * @see org.apache.tapestry.services.TapestryModule#contributeMarkupRenderer(org.apache.tapestry.ioc.OrderedConfiguration,
  *      org.apache.tapestry.Asset, org.apache.tapestry.Asset, ValidationMessagesSource,
  *      org.apache.tapestry.ioc.services.SymbolSource, AssetSource)
  */
 public interface MarkupRendererFilter
 {
@@ -12,18 +12,18 @@
 
 /**
- * Filter interface for {@link org.apache.tapestry.services.MarkupRenderer}, which allows for code to execute before
+ * Filter interface for {@link org.apache.tapestry5.services.MarkupRenderer}, which allows for code to execute before
  * and/or after the main rendering process.  Typically, this is to allow for the placement of {@linkplain
@@ -12,18 +12,18 @@
  *
- * @see org.apache.tapestry.services.TapestryModule#contributeMarkupRenderer(org.apache.tapestry.ioc.OrderedConfiguration,
- *      org.apache.tapestry.Asset, org.apache.tapestry.Asset, ValidationMessagesSource,
- *      org.apache.tapestry.ioc.services.SymbolSource, AssetSource)
+ * @see org.apache.tapestry5.services.TapestryModule#contributeMarkupRenderer(org.apache.tapestry5.ioc.OrderedConfiguration,
+ *      org.apache.tapestry5.Asset, org.apache.tapestry5.Asset, ValidationMessagesSource,
+ *      org.apache.tapestry5.ioc.services.SymbolSource, AssetSource)
  */
 public interface MarkupRendererFilter

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupWriterFactory.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupWriterFactory.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupWriterFactory.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MarkupWriterFactory.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.ContentType;
-import org.apache.tapestry.MarkupWriter;
+import org.apache.tapestry5.ContentType;
+import org.apache.tapestry5.MarkupWriter;
 
 /**
  * Source for {@link org.apache.tapestry.MarkupWriter} instances.
  */
 public interface MarkupWriterFactory
 {
@@ -26,7 +26,7 @@
      * Creates a markup writer for a particular content type.
      *
      * @param contentType type of content generated by the markup write; used to control the type of {@link
-     *                    org.apache.tapestry.dom.MarkupModel} used with the {@link org.apache.tapestry.dom.Document}
+     *                    org.apache.tapestry5.dom.MarkupModel} used with the {@link org.apache.tapestry5.dom.Document}
      *                    the backs the markup writer.
      */
     MarkupWriter newMarkupWriter(ContentType contentType);
@@ -12,13 +12,13 @@
 
 /**
- * Source for {@link org.apache.tapestry.MarkupWriter} instances.
+ * Source for {@link org.apache.tapestry5.MarkupWriter} instances.
  */
 public interface MarkupWriterFactory

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MetaDataLocator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MetaDataLocator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MetaDataLocator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MetaDataLocator.java Tue May 20 11:51:35 2008
@@ -12,19 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.ComponentResources;
+import org.apache.tapestry5.ComponentResources;
 
 /**
  * Used to lookup meta data concerning a particular component. The primary source of meta data is the meta data defined
  * for the component, accessed via {@link org.apache.tapestry.model.ComponentModel#getMeta(String)}. This includes meta
  * data defined by base classes. When meta-data for a particular component can not be found, a search works up the
  * containment hierarchy (to the component's container, and the container's container, and so on). If <em>that</em>
  * proves unfruitful, a system of defaults is provided by configuration and matched against the containing page's
  * logical name.
  * <p/>
- * Finally, if no metadata is available, then {@link org.apache.tapestry.ioc.services.SymbolSource#valueForSymbol(String)}
+ * Finally, if no metadata is available, then {@link org.apache.tapestry5.ioc.services.SymbolSource#valueForSymbol(String)}
  * is used to obtain a value.
  */
 public interface MetaDataLocator
@@ -12,19 +12,19 @@
 /**
  * Used to lookup meta data concerning a particular component. The primary source of meta data is the meta data defined
- * for the component, accessed via {@link org.apache.tapestry.model.ComponentModel#getMeta(String)}. This includes meta
+ * for the component, accessed via {@link org.apache.tapestry5.model.ComponentModel#getMeta(String)}. This includes meta
  * data defined by base classes. When meta-data for a particular component can not be found, a search works up the
  * containment hierarchy (to the component's container, and the container's container, and so on). If <em>that</em>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MethodFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/MethodFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/NullFieldStrategySource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/NullFieldStrategySource.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.NullFieldStrategy;
+import org.apache.tapestry5.NullFieldStrategy;
 
 /**
  * A source for {@link org.apache.tapestry.NullFieldStrategy} instances based on a logical name.
  *
- * @see TapestryModule#contributeNullFieldStrategySource(org.apache.tapestry.ioc.MappedConfiguration)
+ * @see TapestryModule#contributeNullFieldStrategySource(org.apache.tapestry5.ioc.MappedConfiguration)
  */
 public interface NullFieldStrategySource
 {
@@ -12,14 +12,14 @@
 
 /**
- * A source for {@link org.apache.tapestry.NullFieldStrategy} instances based on a logical name.
+ * A source for {@link org.apache.tapestry5.NullFieldStrategy} instances based on a logical name.
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ObjectRenderer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ObjectRenderer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ObjectRenderer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ObjectRenderer.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.MarkupWriter;
+import org.apache.tapestry5.MarkupWriter;
 
 /**
  * A strategy interface used for converting an object into markup that describes that object. This is primarily used in
  * terms of an {@link org.apache.tapestry.services.ExceptionReporter} page.
  */
 public interface ObjectRenderer<T>
 {
@@ -12,13 +12,13 @@
 /**
  * A strategy interface used for converting an object into markup that describes that object. This is primarily used in
- * terms of an {@link org.apache.tapestry.services.ExceptionReporter} page.
+ * terms of an {@link org.apache.tapestry5.services.ExceptionReporter} page.
  */
 public interface ObjectRenderer<T>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestHandler.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestHandler.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.io.IOException;
 
@@ -25,7 +25,7 @@
 {
     /**
      * Invoked to activate and render a page. In certain cases, based on values returned when activating the page, a
      * {@link org.apache.tapestry.services.ComponentEventResultProcessor} may be used to send an alternate response
      * (typically, a redirect).
      *
      * @param parameters defines the page name and activation context
@@ -25,7 +25,7 @@
     /**
      * Invoked to activate and render a page. In certain cases, based on values returned when activating the page, a
-     * {@link org.apache.tapestry.services.ComponentEventResultProcessor} may be used to send an alternate response
+     * {@link org.apache.tapestry5.services.ComponentEventResultProcessor} may be used to send an alternate response
      * (typically, a redirect).
      *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestParameters.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestParameters.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestParameters.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PageRenderRequestParameters.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.EventContext;
-import org.apache.tapestry.ioc.internal.util.Defense;
+import org.apache.tapestry5.EventContext;
+import org.apache.tapestry5.ioc.internal.util.Defense;
 
 /**
  * Used with {@link org.apache.tapestry.services.PageRenderRequestHandler} and {@link
  * org.apache.tapestry.services.PageRenderRequestFilter} to define the logical page name and activation context for the
  * request.
  */
 public class PageRenderRequestParameters
@@ -12,14 +12,14 @@
 
 /**
- * Used with {@link org.apache.tapestry.services.PageRenderRequestHandler} and {@link
- * org.apache.tapestry.services.PageRenderRequestFilter} to define the logical page name and activation context for the
+ * Used with {@link org.apache.tapestry5.services.PageRenderRequestHandler} and {@link
+ * org.apache.tapestry5.services.PageRenderRequestFilter} to define the logical page name and activation context for the
  * request.
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PartialMarkupRenderer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PartialMarkupRenderer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PartialMarkupRenderer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PartialMarkupRenderer.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.MarkupWriter;
+import org.apache.tapestry5.MarkupWriter;
 import org.apache.tapestry5.json.JSONObject;
 
 /**
@@ -24,7 +24,7 @@
  * <p/>
  * <p/>
  * The PartialMarkupRenderer service takes an ordered configuration of {@link PartialMarkupRendererFilter}s.  It can be
  * selected using the {@link org.apache.tapestry.ioc.annotation.Primary} marker annotation.
  */
 public interface PartialMarkupRenderer
 {
@@ -24,7 +24,7 @@
  * <p/>
  * The PartialMarkupRenderer service takes an ordered configuration of {@link PartialMarkupRendererFilter}s.  It can be
- * selected using the {@link org.apache.tapestry.ioc.annotation.Primary} marker annotation.
+ * selected using the {@link org.apache.tapestry5.ioc.annotations.Primary} marker annotation.
  */
 public interface PartialMarkupRenderer

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PartialMarkupRendererFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PartialMarkupRendererFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PartialMarkupRendererFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PartialMarkupRendererFilter.java Tue May 20 11:51:35 2008
@@ -12,19 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.MarkupWriter;
+import org.apache.tapestry5.MarkupWriter;
 import org.apache.tapestry5.json.JSONObject;
 
 /**
  * A filter (the main interface being {@link PartialMarkupRenderer}) applied when performing a partial page render as
  * part of an Ajax-oriented request.  This is similar to {@link org.apache.tapestry.services.MarkupRendererFilter} and
  * filters are often in place so as to contribute {@link org.apache.tapestry.annotation.Environmental} services to the
  * pages and components that render.
  *
  * @see org.apache.tapestry.services.TapestryModule#contributePartialMarkupRenderer(org.apache.tapestry.ioc.OrderedConfiguration,
  *      org.apache.tapestry.Asset, ValidationMessagesSource, org.apache.tapestry.ioc.services.SymbolSource,
  *      AssetSource)
  */
 public interface PartialMarkupRendererFilter
@@ -12,19 +12,19 @@
 /**
  * A filter (the main interface being {@link PartialMarkupRenderer}) applied when performing a partial page render as
- * part of an Ajax-oriented request.  This is similar to {@link org.apache.tapestry.services.MarkupRendererFilter} and
- * filters are often in place so as to contribute {@link org.apache.tapestry.annotation.Environmental} services to the
+ * part of an Ajax-oriented request.  This is similar to {@link org.apache.tapestry5.services.MarkupRendererFilter} and
+ * filters are often in place so as to contribute {@link org.apache.tapestry5.annotations.Environmental} services to the
  * pages and components that render.
  *
@@ -12,19 +12,19 @@
  * pages and components that render.
  *
- * @see org.apache.tapestry.services.TapestryModule#contributePartialMarkupRenderer(org.apache.tapestry.ioc.OrderedConfiguration,
- *      org.apache.tapestry.Asset, ValidationMessagesSource, org.apache.tapestry.ioc.services.SymbolSource,
+ * @see org.apache.tapestry5.services.TapestryModule#contributePartialMarkupRenderer(org.apache.tapestry5.ioc.OrderedConfiguration,
+ *      org.apache.tapestry5.Asset, ValidationMessagesSource, org.apache.tapestry5.ioc.services.SymbolSource,
  *      AssetSource)
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldBundle.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldBundle.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldStrategy.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentFieldStrategy.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.util.Collection;
 
 /**
  * Defines how changes to fields (within components, within pages) may have their values persisted between requests.
  * Different implementations store the field values {@linkplain org.apache.tapestry.internal.services.SessionPersistentFieldStrategy
  * in the session}, {@linkplain org.apache.tapestry.internal.services.ClientPersistentFieldStrategy on the client}, or
  * elsewhere.
  */
 public interface PersistentFieldStrategy
@@ -12,14 +12,14 @@
 /**
  * Defines how changes to fields (within components, within pages) may have their values persisted between requests.
- * Different implementations store the field values {@linkplain org.apache.tapestry.internal.services.SessionPersistentFieldStrategy
- * in the session}, {@linkplain org.apache.tapestry.internal.services.ClientPersistentFieldStrategy on the client}, or
+ * Different implementations store the field values {@linkplain org.apache.tapestry5.internal.services.SessionPersistentFieldStrategy
+ * in the session}, {@linkplain org.apache.tapestry5.internal.services.ClientPersistentFieldStrategy on the client}, or
  * elsewhere.
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentLocale.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PersistentLocale.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyConduitSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyConduitSource.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.PropertyConduit;
+import org.apache.tapestry5.PropertyConduit;
 
 /**
  * A source for {@link org.apache.tapestry.PropertyConduit}s, which can be thought of as a compiled property path
  * expression. PropertyConduits are the basis of the "prop:" binding factory, thus this service defines the expression
  * format used by the {@link org.apache.tapestry.internal.bindings.PropBindingFactory}.
  * <p/>
  * The expression consist of one or more terms, seperated by periods. Each term may be either the name of a JavaBean
  * property, or the name of a method (a method that takes no parameters). Method names are distinguished from property
@@ -12,14 +12,14 @@
 
 /**
- * A source for {@link org.apache.tapestry.PropertyConduit}s, which can be thought of as a compiled property path
+ * A source for {@link org.apache.tapestry5.PropertyConduit}s, which can be thought of as a compiled property path
  * expression. PropertyConduits are the basis of the "prop:" binding factory, thus this service defines the expression
@@ -12,14 +12,14 @@
  * expression. PropertyConduits are the basis of the "prop:" binding factory, thus this service defines the expression
- * format used by the {@link org.apache.tapestry.internal.bindings.PropBindingFactory}.
+ * format used by the {@link org.apache.tapestry5.internal.bindings.PropBindingFactory}.
  * <p/>
  * The expression consist of one or more terms, seperated by periods. Each term may be either the name of a JavaBean

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyEditContext.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyEditContext.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyEditContext.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyEditContext.java Tue May 20 11:51:35 2008
@@ -12,19 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.Field;
-import org.apache.tapestry.FieldValidator;
-import org.apache.tapestry.Translator;
-import org.apache.tapestry.ioc.AnnotationProvider;
-import org.apache.tapestry.ioc.Messages;
+import org.apache.tapestry5.Field;
+import org.apache.tapestry5.FieldValidator;
+import org.apache.tapestry5.Translator;
+import org.apache.tapestry5.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.Messages;
 
 /**
  * Defines a context for editing a property of a bean via {@link org.apache.tapestry.corelib.components.BeanEditor}.
  * This value is made available to blocks via the {@link org.apache.tapestry.annotation.Environmental} annotation.
  *
- * @see org.apache.tapestry.services.BeanBlockSource
+ * @see org.apache.tapestry5.services.BeanBlockSource
  */
 public interface PropertyEditContext extends AnnotationProvider
 {
@@ -42,7 +42,7 @@
     void setPropertyValue(Object value);
 
     /**
-     * Returns the user-presentable label, for use with the {@link org.apache.tapestry.corelib.components.Label}
+     * Returns the user-presentable label, for use with the {@link org.apache.tapestry5.corelib.components.Label}
      * component, or to be integrated into any validation error messages.
      */
     String getLabel();
@@ -57,8 +57,8 @@
     /**
      * Returns the FieldValidator for the field.
      *
-     * @see org.apache.tapestry.beaneditor.Validate
-     * @see org.apache.tapestry.services.FieldValidatorDefaultSource
+     * @see org.apache.tapestry5.beaneditor.Validate
+     * @see org.apache.tapestry5.services.FieldValidatorDefaultSource
      */
     FieldValidator getValidator(Field field);
 
@@ -74,7 +74,7 @@
     Class getPropertyType();
 
     /**
      * Returns the message catalog for the container of the {@link org.apache.tapestry.corelib.components.BeanEditForm},
      * which is the correct place to look for strings used for labels, etc.
      */
     Messages getContainerMessages();
@@ -12,19 +12,19 @@
 
 /**
- * Defines a context for editing a property of a bean via {@link org.apache.tapestry.corelib.components.BeanEditor}.
- * This value is made available to blocks via the {@link org.apache.tapestry.annotation.Environmental} annotation.
+ * Defines a context for editing a property of a bean via {@link org.apache.tapestry5.corelib.components.BeanEditor}.
+ * This value is made available to blocks via the {@link org.apache.tapestry5.annotations.Environmental} annotation.
  *
@@ -74,7 +74,7 @@
 
     /**
-     * Returns the message catalog for the container of the {@link org.apache.tapestry.corelib.components.BeanEditForm},
+     * Returns the message catalog for the container of the {@link org.apache.tapestry5.corelib.components.BeanEditForm},
      * which is the correct place to look for strings used for labels, etc.
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyOutputContext.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/PropertyOutputContext.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestFilter.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.io.IOException;
 
 /**
  * Filter interface for {@link org.apache.tapestry.services.RequestHandler}. Implementations of this interface may be
  * contributed into the RequestHandler service configuration.
  *
  * @see org.apache.tapestry.services.TapestryModule#contributeRequestHandler(org.apache.tapestry.ioc.OrderedConfiguration,
  *      Context, RequestExceptionHandler, long, long, org.apache.tapestry.internal.services.LocalizationSetter,
  *      RequestFilter)
  */
 public interface RequestFilter
@@ -12,16 +12,16 @@
 
 /**
- * Filter interface for {@link org.apache.tapestry.services.RequestHandler}. Implementations of this interface may be
+ * Filter interface for {@link org.apache.tapestry5.services.RequestHandler}. Implementations of this interface may be
  * contributed into the RequestHandler service configuration.
  *
@@ -12,16 +12,16 @@
  * contributed into the RequestHandler service configuration.
  *
- * @see org.apache.tapestry.services.TapestryModule#contributeRequestHandler(org.apache.tapestry.ioc.OrderedConfiguration,
- *      Context, RequestExceptionHandler, long, long, org.apache.tapestry.internal.services.LocalizationSetter,
+ * @see org.apache.tapestry5.services.TapestryModule#contributeRequestHandler(org.apache.tapestry5.ioc.OrderedConfiguration,
+ *      Context, RequestExceptionHandler, long, long, org.apache.tapestry5.internal.services.LocalizationSetter,
  *      RequestFilter)
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestGlobals.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/RequestGlobals.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ServletApplicationInitializerFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ServletApplicationInitializerFilter.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import javax.servlet.ServletContext;
 
 /**
  * Filter interface for {@link org.apache.tapestry.services.ServletApplicationInitializer}.
  *
- * @see org.apache.tapestry.services.ServletApplicationInitializer
+ * @see org.apache.tapestry5.services.ServletApplicationInitializer
  */
 public interface ServletApplicationInitializerFilter
 {
@@ -12,14 +12,14 @@
 
 /**
- * Filter interface for {@link org.apache.tapestry.services.ServletApplicationInitializer}.
+ * Filter interface for {@link org.apache.tapestry5.services.ServletApplicationInitializer}.
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Session.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Session.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================